@@ -1,12 +1,10 @@
-/* ============================================================
- *
+/*
  * SPDX-FileCopyrightText: 2009 Kare Sars <kare dot sars at iki dot fi>
  * SPDX-FileCopyrightText: 2014 Gregor Mitsch : port to KDE5 frameworks
  * SPDX-FileCopyrightText: 2021 Alexander Stippich <a.stippich@gmx.net>
  *
  * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
- *
- * ============================================================ */
+ */
 
 #ifndef KSANE_WIDGET_PRIVATE_H
 #define KSANE_WIDGET_PRIVATE_H
@@ -22,7 +20,9 @@
 #include <QToolButton>
 #include <QSet>
 
-#include "ksanecore.h"
+#include <Interface>
+#include <Option>
+
 #include "ksanewidget.h"
 #include "ksaneoptionwidget.h"
 #include "ksaneviewer.h"
@@ -49,8 +49,7 @@ public:
     void createOptInterface();
     void updatePreviewSize();
     void setBusy(bool busy);
-    KSaneOptionWidget *createOptionWidget(QWidget *parent, KSaneOption *option);
-    KSaneWidget::ImageFormat getImgFormat(const QImage &image);
+    KSaneOptionWidget *createOptionWidget(QWidget *parent, KSaneCore::Option *option);
 
     float ratioToScanAreaX(float ratio);
     float ratioToScanAreaY(float ratio);
@@ -67,15 +66,15 @@ public:
 public Q_SLOTS:
     void startFinalScan();
     void startPreviewScan();
-    void scanDone(KSaneCore::KSaneScanStatus status, const QString &strStatus);
-    void previewScanDone(KSaneCore::KSaneScanStatus status, const QString &strStatus);
-    void oneFinalScanDone(KSaneCore::KSaneScanStatus status, const QString &strStatus);
+    void scanDone(KSaneCore::Interface::ScanStatus status, const QString &strStatus);
+    void previewScanDone(KSaneCore::Interface::ScanStatus status, const QString &strStatus);
+    void oneFinalScanDone(KSaneCore::Interface::ScanStatus status, const QString &strStatus);
     void updateProgress(int progress);
     void updateCountDown(int remainingSeconds);
     void handleSelection(float tl_x, float tl_y, float br_x, float br_y);
-    void signalDevListUpdate(const QList<KSaneCore::DeviceInfo> &deviceList);
+    void signalDevListUpdate(const QList<KSaneCore::DeviceInformation*> &deviceList);
     void imageReady(const QImage &image);
-    
+
 private Q_SLOTS:
 
     void setTLX(const QVariant &x);
@@ -89,16 +88,16 @@ private Q_SLOTS:
     void updateScanSelection();
     void setPossibleScanSizes();
     void setPageSize(int index);
-    
+
     void updateCommonGamma();
     void updatePreviewViewer();
-    
-public:
-    void alertUser(KSaneCore::KSaneScanStatus status, const QString &strStatus);
 
 public:
-    KSaneCore          *m_ksaneCoreInterface;
-    
+    void alertUser(KSaneCore::Interface::ScanStatus status, const QString &strStatus);
+
+public:
+    KSaneCore::Interface   *m_ksaneCoreInterface;
+
     // backend independent
     QTabWidget         *m_optsTabWidget;
     QScrollArea        *m_basicScrollA;
@@ -139,26 +138,26 @@ public:
 
     // Option variables
     QSet<QString>            m_handledOptions;
-    KSaneOption        *m_optSource;
-    KSaneOption        *m_optNegative;
-    KSaneOption        *m_optFilmType;
-    KSaneOption        *m_optMode;
-    KSaneOption        *m_optDepth;
-    KSaneOption        *m_optRes;
-    KSaneOption        *m_optResX;
-    KSaneOption        *m_optResY;
-    KSaneOption        *m_optTlX;
-    KSaneOption        *m_optTlY;
-    KSaneOption        *m_optBrX;
-    KSaneOption        *m_optBrY;
-    KSaneOption        *m_optPreview;
-    KSaneOption        *m_optGamR;
-    KSaneOption        *m_optGamG;
-    KSaneOption        *m_optGamB;
-    KSaneOption        *m_optInvert;
+    KSaneCore::Option        *m_optSource;
+    KSaneCore::Option        *m_optNegative;
+    KSaneCore::Option        *m_optFilmType;
+    KSaneCore::Option        *m_optMode;
+    KSaneCore::Option        *m_optDepth;
+    KSaneCore::Option        *m_optRes;
+    KSaneCore::Option        *m_optResX;
+    KSaneCore::Option        *m_optResY;
+    KSaneCore::Option        *m_optTlX;
+    KSaneCore::Option        *m_optTlY;
+    KSaneCore::Option        *m_optBrX;
+    KSaneCore::Option        *m_optBrY;
+    KSaneCore::Option        *m_optPreview;
+    KSaneCore::Option        *m_optGamR;
+    KSaneCore::Option        *m_optGamG;
+    KSaneCore::Option        *m_optGamB;
+    KSaneCore::Option        *m_optInvert;
     LabeledCheckbox    *m_splitGamChB;
     LabeledGamma       *m_commonGamma;
-    KSaneOption        *m_optWaitForBtn;
+    KSaneCore::Option        *m_optWaitForBtn;
 
     // preview variables
     float               m_previewWidth;
@@ -167,7 +166,7 @@ public:
     QImage              m_previewImg;
     bool                m_isPreview;
     bool                m_autoSelect;
-    
+
     bool                m_cancelMultiScan = false;
     bool                m_scanOngoing = false;
     int                 m_selIndex;
