@@ -1,11 +1,9 @@
-/* ============================================================
- *
+/*
  * SPDX-FileCopyrightText: 2007-2011 Kare Sars <kare.sars@iki .fi>
  * SPDX-FileCopyrightText: 2014 Gregor Mitsch : port to KDE5 frameworks
  *
  * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
- *
- * ============================================================ */
+ */
 
 #ifndef LABELED_ENTRY_H
 #define LABELED_ENTRY_H
@@ -38,7 +36,7 @@ public:
      * \param text is the text describing the entry.
      */
     LabeledEntry(QWidget *parent, const QString &text);
-    LabeledEntry(QWidget *parent, KSaneOption *option);
+    LabeledEntry(QWidget *parent, KSaneCore::Option *option);
     ~LabeledEntry() override;
     void setText(const QString &text);
 
